@@ -190,7 +190,7 @@ buddy_idle_changed_cb(GaimBuddy *buddy)
 	idle = (buddy->idle > 0);
 
 	if (idle)
-		idle_start_time = buddy->idle;
+		idle_start_time = time(NULL) - buddy->idle;
 #endif
 
 	if (idle != galago_presence_is_idle(presence))
